Crate reverie

Crate reverie 

Re-exports

pub use algebra::*;

Modules

algebra
crypto
generator
interpreter
proof
transcript

Macros

HASH

Enums

CombineOperation
Wraps Operation to define a field for each gate. Also supports conversions and metadata.
Operation
Defines the individual logic gate operations we can support

Constants

BATCH_SIZE
number of shares per batch e.g. in the case of GF2, each batch is 128-bits, hence a patch per player, per instance (64 in total) is 128 shares
PACKED
PLAYERS

Functions

evaluate_composite_program
Evaluates a composite program (in the clear). Uses assert! to check AssertZero gates
largest_wires
Get the largest (arithmetic, boolean) wires in a program so we know how much memory to allocate. Respects size hints, if present at the start of the circuit