pub enum ProcessAlarmSignalErrorKind {
Unsupported,
Invalid,
Backend,
}Expand description
Why a process-alarm operation was refused without changing backend state.
Variants
Unsupported
This backend, callback, receiver configuration or producer is unsupported.
Invalid
The complete metadata or current receiver identity is invalid.
Backend
A backend operation failed before publication.