pub enum SignalObservationStep {
Ignored {
dequeue: DequeueId,
},
Suppressed {
dequeue: DequeueId,
},
Reblocked {
dequeue: DequeueId,
domain: PendingDomain,
},
Caught {
dequeue: DequeueId,
},
Fatal {
dequeue: DequeueId,
},
}Expand description
Committed selection outcomes, in their real dequeue order.
Variants
Ignored
Current disposition ignores the selected event.
Suppressed
The Tool suppressed the selected event.
Reblocked
The Tool replacement was requeued in its original domain.
Caught
One caught event was reserved for the existing frame path.
Fatal
One fatal event was reserved for the existing default action.