pub struct Backtrace { /* private fields */ }Expand description
A backtrace is a list of stack frames. These stack frames may have originated from a remote process.
Implementations
Sourceimpl Backtrace
impl Backtrace
Sourcepub fn new(thread_id: Pid, frames: Vec<Frame>) -> Self
pub fn new(thread_id: Pid, frames: Vec<Frame>) -> Self
Creates a backtrace from a thread ID and frames.
Sourcepub fn pretty(&self) -> Result<PrettyBacktrace, Error>
pub fn pretty(&self) -> Result<PrettyBacktrace, Error>
Generates a pretty backtrace that includes file and line information for each frame.
Sourcepub fn force_pretty(&self) -> PrettyBacktrace
pub fn force_pretty(&self) -> PrettyBacktrace
Generates a pretty backtrace that may includes file and line information for each frame, if available.
Sourcepub fn iter(&self) -> impl Iterator<Item = &Frame>
pub fn iter(&self) -> impl Iterator<Item = &Frame>
Returns an iterator over the frames in the backtrace.
Sourcepub fn thread_name(&self) -> Option<String>
pub fn thread_name(&self) -> Option<String>
Returns the name of the thread for this backtrace.