pub struct PrettyBacktrace { /* private fields */ }Expand description
A backtrace with file and line information. This is more heavy-weight than a normal backtrace.
Implementations
Sourceimpl PrettyBacktrace
impl PrettyBacktrace
Sourcepub fn iter(&self) -> impl Iterator<Item = &PrettyFrame>
pub fn iter(&self) -> impl Iterator<Item = &PrettyFrame>
Returns an iterator over the frames in the backtrace.
Sourcepub fn thread_name(&self) -> Option<String>
pub fn thread_name(&self) -> Option<String>
Returns the name of the thread for this backtrace.