Re-exports
pub use algebra::*;
Modules
Macros
Enums
- Combine
Operation - Wraps
Operationto define a field for each gate. Also supports conversions and metadata. - Operation
- Defines the individual logic gate operations we can support
Constants
- BATCH_
SIZE - number of shares per batch e.g. in the case of GF2, each batch is 128-bits, hence a patch per player, per instance (64 in total) is 128 shares
- PACKED
- PLAYERS
Functions
- evaluate_
composite_ program - Evaluates a composite program (in the clear). Uses assert! to check
AssertZerogates - largest_
wires - Get the largest (arithmetic, boolean) wires in a program so we know how much memory to allocate. Respects size hints, if present at the start of the circuit